dfwinreg package
================

Submodules
----------

dfwinreg.creg module
--------------------

.. automodule:: dfwinreg.creg
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.decorators module
--------------------------

.. automodule:: dfwinreg.decorators
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.definitions module
---------------------------

.. automodule:: dfwinreg.definitions
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.errors module
----------------------

.. automodule:: dfwinreg.errors
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.fake module
--------------------

.. automodule:: dfwinreg.fake
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.glob2regex module
--------------------------

.. automodule:: dfwinreg.glob2regex
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.interface module
-------------------------

.. automodule:: dfwinreg.interface
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.key\_paths module
--------------------------

.. automodule:: dfwinreg.key_paths
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.regf module
--------------------

.. automodule:: dfwinreg.regf
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.registry module
------------------------

.. automodule:: dfwinreg.registry
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.registry\_searcher module
----------------------------------

.. automodule:: dfwinreg.registry_searcher
   :members:
   :undoc-members:
   :show-inheritance:

dfwinreg.virtual module
-----------------------

.. automodule:: dfwinreg.virtual
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dfwinreg
   :members:
   :undoc-members:
   :show-inheritance:
